## AAMT 项目模版
> 用于生成 基于pytest的接口自动化脚手架

python 版本

> 3.9

安装最新版本

> pip install aamt

指定版本安装

> pip install aamt==0.2.0

升级aamt

> pip install -U aamt

创建项目脚手架 

> aamt startproject demo

创建项目脚手架(自动创建虚拟环境)

> aamt startproject demo -venv

外网速度慢，pandas可能安装失败，推荐用国内镜像

> pip --default-timeout=6000 install -i https://pypi.tuna.tsinghua.edu.cn/simple aamt



